@@ -66,6 +66,17 @@ static int _no_lock_resource(struct cmd_context *cmd, const char *resource,
 	return 1;
 }
 
+static int _readonly_lock_resource(struct cmd_context *cmd,
+				   const char *resource,
+				   uint32_t flags)
+{
+	if ((flags & LCK_TYPE_MASK) == LCK_WRITE) {
+		log_error("Write locks are prohibited with --ignorelockingfailure.");
+		return 0;
+	}
+	return _no_lock_resource(cmd, resource, flags);
+}
+
 int init_no_locking(struct locking_type *locking, struct cmd_context *cmd __attribute((unused)))
 {
 	locking->lock_resource = _no_lock_resource;
@@ -75,3 +86,13 @@ int init_no_locking(struct locking_type *locking, struct cmd_context *cmd __attr
 
 	return 1;
 }
+
+int init_readonly_locking(struct locking_type *locking, struct cmd_context *cmd __attribute((unused)))
+{
+	locking->lock_resource = _readonly_lock_resource;
+	locking->reset_locking = _no_reset_locking;
+	locking->fin_locking = _no_fin_locking;
+	locking->flags = 0;
+
+	return 1;
+}
