@@ -17,7 +17,12 @@
 #include "toolcontext.h"
 #include "locking.h"
 
-lvm_t lvm_create(const char *system_dir)
+const char *lvm_library_get_version(void)
+{
+	return LVM_VERSION;
+}
+
+lvm_t lvm_init(const char *system_dir)
 {
 	struct cmd_context *cmd;
 
@@ -29,6 +34,10 @@ lvm_t lvm_create(const char *system_dir)
 	cmd = create_toolcontext(1, system_dir);
 	if (!cmd)
 		return NULL;
+
+	if (stored_errno())
+		return (lvm_t) cmd;
+
 	/*
 	 * FIXME: if an non memory error occured, return the cmd (maybe some
 	 * cleanup needed).
@@ -42,7 +51,7 @@ lvm_t lvm_create(const char *system_dir)
 	if (!init_locking(-1, cmd)) {
 		/* FIXME: use EAGAIN as error code here */
 		log_error("Locking initialisation failed.");
-		lvm_destroy((lvm_t) cmd);
+		lvm_quit((lvm_t) cmd);
 		return NULL;
 	}
 	/*
@@ -55,14 +64,36 @@ lvm_t lvm_create(const char *system_dir)
 	return (lvm_t) cmd;
 }
 
-void lvm_destroy(lvm_t libh)
+void lvm_quit(lvm_t libh)
 {
-	/* FIXME: error handling */
 	destroy_toolcontext((struct cmd_context *)libh);
 }
 
-int lvm_reload_config(lvm_t libh)
+int lvm_config_reload(lvm_t libh)
 {
 	/* FIXME: re-init locking needed here? */
-	return refresh_toolcontext((struct cmd_context *)libh);
+	if (!refresh_toolcontext((struct cmd_context *)libh))
+		return -1;
+	return 0;
+}
+
+/*
+ * FIXME: submit a patch to document the --config option
+ */
+int lvm_config_override(lvm_t libh, const char *config_settings)
+{
+	struct cmd_context *cmd = (struct cmd_context *)libh;
+	if (override_config_tree_from_string(cmd, config_settings))
+		return -1;
+	return 0;
+}
+
+int lvm_errno(lvm_t libh)
+{
+	return stored_errno();
+}
+
+const char *lvm_errmsg(lvm_t libh)
+{
+	return stored_errmsg();
 }
