@@ -482,6 +482,8 @@ int process_each_vg(struct cmd_context *cmd, int argc, char **argv,
 				if (!validate_name(vg_name + 1)) {
 					log_error("Skipping invalid tag %s",
 						  vg_name);
+					if (ret_max < EINVALID_CMD_LINE)
+						ret_max = EINVALID_CMD_LINE;
 					continue;
 				}
 				if (!str_list_add(cmd->mem, &tags,
@@ -497,6 +499,8 @@ int process_each_vg(struct cmd_context *cmd, int argc, char **argv,
 			if (strchr(vg_name, '/')) {
 				log_error("Invalid volume group name: %s",
 					  vg_name);
+				if (ret_max < EINVALID_CMD_LINE)
+					ret_max = EINVALID_CMD_LINE;
 				continue;
 			}
 			if (!str_list_add(cmd->mem, &arg_vgnames,
@@ -1001,7 +1005,7 @@ static int _create_pv_entry(struct dm_pool *mem, struct pv_list *pvl,
 
 	if (allocatable_only &&
 	    (pvl->pv->pe_count == pvl->pv->pe_alloc_count)) {
-		log_err("No free extents on physical volume \"%s\"", pvname);
+		log_error("No free extents on physical volume \"%s\"", pvname);
 		return 1;
 	}
 
@@ -1013,7 +1017,7 @@ static int _create_pv_entry(struct dm_pool *mem, struct pv_list *pvl,
 	
 	if (!new_pvl) {
 		if (!(new_pvl = dm_pool_alloc(mem, sizeof(*new_pvl)))) {
-			log_err("Unable to allocate physical volume list.");
+			log_error("Unable to allocate physical volume list.");
 			return 0;
 		}
 
@@ -1087,8 +1091,8 @@ struct dm_list *create_pv_list(struct dm_pool *mem, struct volume_group *vg, int
 		}
 
 		if (!(pvl = find_pv_in_vg(vg, pvname))) {
-			log_err("Physical Volume \"%s\" not found in "
-				"Volume Group \"%s\"", pvname, vg->name);
+			log_error("Physical Volume \"%s\" not found in "
+				  "Volume Group \"%s\"", pvname, vg->name);
 			return NULL;
 		}
 		if (!_create_pv_entry(mem, pvl, colon, allocatable_only, r))
